from atttest.__init__ import *

def func_test():
    print("Successfully Imported test.py file")

def print_name(name):
    print(f'Hello {name}')

def print_test_count(count):
    print_count(count)
